$NOLIST
$SKIP
;-------------------------------------------------------------------------------
;
; This product is licensed for use only under the terms and conditions of 
; the PG5 Licensing Agreement.
;
; Copyright (c) 2011-2013 Saia Burgess Controls AG. All rights reserved.
;
;-------------------------------------------------------------------------------
;
; HTTPC_Errors.inc
;
; Global list of error codes for Shared ODM and HTTP client libraries.
; 
; Author: Arkadiusz Jestratjew.
;
; Version V1.0.110
;
;-------------------------------------------------------------------------------
;
; List of modifications:
;
; 2011.11.25           Version Beta 0.4.25
; 2012.01.01           _HTTPC.ERRORS.WEB_URL_TOO_LONG added.
; 2012.09.11           _HTTPC.ERRORS.WEB_AUTHENTICATION_FAILED added
; 2012.09.14           Version 1.0.30
; 2012.10.01           _HTTPC.STATUS.INVALID_LOCAL_MEDIA, LOCAL_AREA_OVERFLOW added
; 2012.12.20           Version 1.0.100
; 2013.11.01           Version 1.0.110
;
;-------------------------------------------------------------------------------
$ENDSKIP

$IFNDEF _LIBVERS_._SAIA_HTTPC_ERRORS
_LIBVERS_._SAIA_HTTPC_ERRORS EQU 0100110         ;HTTP Client Library Errors

$SKIP
;-------------------------------------------------------------------------------
;
; ErrorCode format for SOdm and HTTP client libraries
;
; [ 31....................16 | 15.....12 | 11.....8 7..........0 ]
; [          Reserved        | Subsystem |       Error code      ]
; 
; Subsystem codes:
;   0000 - reserved
;   0001 - Shared ODM errors and HTTP client errors
;   0010 - DBLIB errors
;   0011 - File system errors, DNS errors
;   01xx - reserved
;   1xxx - reserved
;
;-------------------------------------------------------------------------------
$ENDSKIP

;-------------------------------------------------------------------------------
; Error codes
;-------------------------------------------------------------------------------

_HTTPC.ERRORS.NO_ERROR EQU 0                     ; No error

_HTTPC.ERRORS.SODM EQU 1                         ; Subsystem Shared ODM Management
_HTTPC.ERRORS.WEB EQU 1                          ; Subsystem HTTP Client
_HTTPC.ERRORS.DBLIB EQU 2                        ; Subsystem DBLib
_HTTPC.ERRORS.FS EQU 3                           ; Subsystem File System
_HTTPC.ERRORS.DNS EQU 3                          ; Subsystem DNS

_HTTPC.ERRORS.SODM_DIAGNOSTICS EQU 1000H         ; Shared ODM Management library error
_HTTPC.ERRORS.WEB_DIAGNOSTICS EQU 1100H          ; HTTP Client error

_HTTPC.ERRORS.DBLIB_DIAGNOSTICS EQU 2000H        ; DBLib unexpected error. See bits [11..0] for DBLib error code
_HTTPC.ERRORS.FS_DIAGNOSTICS EQU 3000H           ; File System error. See bits [11..0] for error code
_HTTPC.ERRORS.DNS_DIAGNOSTICS EQU 3000H          ; DNS error. See bits [11..0] for error code

_HTTPC.ERRORS.SODM_IPLIB_DIAGNOSTICS EQU 1000H   ; General TCP/IP communication error 
_HTTPC.ERRORS.SODM_NOT_AVAILABLE EQU 1001H       ; ODM mode is not available, use Hardware Configurator to Initialize Open Data Mode
_HTTPC.ERRORS.SODM_INVALID_PARAMETER EQU 1010H   ; Invalid parameter value
_HTTPC.ERRORS.SODM_INVALID_IP_ADDRESS EQU 1011H  ; Invalid IP address
_HTTPC.ERRORS.SODM_INVALID_NETWORK_NODE EQU 1012H ; Invalid network node number or node undefined
_HTTPC.ERRORS.SODM_CHANNEL_OPEN EQU 1013H        ; Specified operation cannot be executed while the channel is open  
_HTTPC.ERRORS.SODM_TELEGRAM_READ_TIMEOUT EQU 1021H ; Telegram not read with specified timeout, use Hardware Configurator to increase Telegram Reading Timeout
_HTTPC.ERRORS.SODM_CONNECT_TIMEOUT EQU 1022H     ; Connection not established within specified timeout
_HTTPC.ERRORS.SODM_EXCHANGE_TIMEOUT EQU 1023H    ; Exchange not executed completely within specified timeout
_HTTPC.ERRORS.SODM_CHANNEL_ALREADY_USED EQU 1024H ; ODM channel is already used

_HTTPC.ERRORS.WEB_PROTOCOL_ERROR EQU 1100H       ; HTTP protocol error
_HTTPC.ERRORS.WEB_DATA_LOST EQU 1101H            ; Data lost during overlayed processing
_HTTPC.ERRORS.WEB_INVALID_PARAMETER EQU 1102H    ; Invalid parameter value
_HTTPC.ERRORS.WEB_HEADER_PROC_ERROR EQU 1103H    ; Header processor error
_HTTPC.ERRORS.WEB_ENTITY_PROC_ERROR EQU 1104H    ; Entity processor error
_HTTPC.ERRORS.WEB_FS_READ_ERROR EQU 1105H        ; Unexpected length of data read from File System
_HTTPC.ERRORS.WEB_FS_WRITE_ERROR EQU 1106H       ; Unexpected length of data written to File System
_HTTPC.ERRORS.WEB_SRC_TOO_SHORT EQU 1107H        ; Source TEXT/DB shorter than specified
_HTTPC.ERRORS.WEB_CONCURRENCY_ERROR EQU 1108H    ; Concurrency error: parameter value changed during exchange 
_HTTPC.ERRORS.WEB_TOO_MANY_CHANNELS EQU 1109H    ; Too many channels
_HTTPC.ERRORS.WEB_CONNECTION_DROP EQU 110AH      ; Connection closed by the remote host
_HTTPC.ERRORS.WEB_BAD_HOST_NAME EQU 110BH        ; Invalid host name for DNS query
_HTTPC.ERRORS.WEB_NEGATIVE_START_OFFSET EQU 110CH ; Negative start offset ('Skip first bytes' or 'Offset' FBox parameter)
_HTTPC.ERRORS.WEB_URL_TOO_LONG EQU 110DH         ; Request URL too long
_HTTPC.ERRORS.WEB_AUTHENTICATION_FAILED EQU 110EH ; Web authentication failed
                                                                      
; DNS errors = _HTTPC.ERRORS.DNS_DIAGNOSTICS | (negative error code & 0x0FFF)
_HTTPC.ERRORS.DNS_PENDING_QUERY EQU 4000H - 400  ; Executing DNS query
_HTTPC.ERRORS.DNS_NO_RESOURCE EQU 4000H - 399    ; No resource to execute DNS query
_HTTPC.ERRORS.DNS_HOST_NOT_FOUND EQU 4000H - 398 ; Host not found
_HTTPC.ERRORS.DNS_PROTOCOL_ERROR EQU 4000H - 397 ; DNS error
_HTTPC.ERRORS.DNS_BAD_PARAMETER EQU 4000H - 396  ; Bad parameter

;-------------------------------------------------------------------------------
; Exchange status codes
;-------------------------------------------------------------------------------
                       
; Convention:
; HTTP Exchange status codes >= 1000 means that HTTP Response Status code is 2xx
; HTTP Exchange status codes < 1000 are HTTP Response Status codes

_HTTPC.STATUS.SUCCESS EQU 1000                   ; Exchange finished successfully
_HTTPC.STATUS.ERROR EQU 2000                     ; General error, use specific codes below

; Exchange status codes for tokenized response processor
_HTTPC.STATUS.EXCESS_TOKEN EQU 2001              ; Received greater number of tokens than expected
_HTTPC.STATUS.MISSING_TOKEN EQU 2002             ; Received less number of tokens than expected
_HTTPC.STATUS.UNRECOGNIZED_TOKEN EQU 2003        ; The response contains unrecognized token string
_HTTPC.STATUS.EMPTY_TOKEN EQU 2004               ; The last token is empty

; Exchange status code for arithmetic processing errors
_HTTPC.STATUS.ARITHMETIC_OVERFLOW EQU 2101       ; Arithmetic overflow/underflow
_HTTPC.STATUS.ARITHMETIC_DIV_BY_0 EQU 2102       ; Arithmetic division by zero
_HTTPC.STATUS.ARITHMETIC_PRECISION_LOST EQU 2103 ; Arithmetic precision lost

; Exchange status codes for PCD Web Server - see PCD Web Server Classic Reference Manual
_HTTPC.STATUS.PCD_BAD_SYNTAX EQU 2301            ; Tag too long or invalid tag syntax (second comma not found).
_HTTPC.STATUS.PCD_COMPONENT_NOT_FOUND EQU 2302   ; The specified component do not exist on this system. 
_HTTPC.STATUS.PCD_PERMISSION_DENIED EQU 2303     ; Either read/write access to media not permitted.
_HTTPC.STATUS.PCD_TAG_NOT_FOUND EQU 2304         ; CFG/SYS Tag not defined in the registry.
_HTTPC.STATUS.PCD_TAG_READ_ONLY EQU 2305         ; CFG/SYS Tag is write protected.
_HTTPC.STATUS.PCD_CONFIG_NOT_FOUND EQU 2306      ; CFG/SYS Tag not defined in the registry.
_HTTPC.STATUS.PCD_NO_DATA_PROXY EQU 2307         ; Tag could not be resolved or forwarded.
_HTTPC.STATUS.PCD_CGI_ERROR EQU 2308             ; CGI Command could not be executed - retry after some time.
_HTTPC.STATUS.PCD_CGI_SYNTAX_ERROR EQU 2309      ; CGI Command has an syntax error.
_HTTPC.STATUS.PCD_CGI_FILE_ERROR EQU 2310        ; CGI File name length exceeded or access failed.

_HTTPC.STATUS.PPO_MEDIA_UNKNOWN EQU 2401         ; Media is invalid.
_HTTPC.STATUS.PPO_MEDIA_UNKNOWN2 EQU 2402        ; Media is invalid. Typo in the response sent by some PCD FW versions
_HTTPC.STATUS.PPO_FORMAT_UNKNOWN EQU 2403        ; Format is invalid.
_HTTPC.STATUS.PPO_FORMAT_UNKNOWN2 EQU 2404       ; Format is invalid. Typo in the response sent by some PCD FW versions.
_HTTPC.STATUS.PPO_FORMAT_NOTSUPPORTED EQU 2405   ; Format is not supported for this media type.
_HTTPC.STATUS.PPO_SYNTAX_ERROR EQU 2406          ; Web Tag syntax was not correctly applied.
_HTTPC.STATUS.PPO_ACCESS_ERROR EQU 2407          ; PLC Web Tag PLC data currently not accessible.
_HTTPC.STATUS.PPO_AREA_OVERFLOW EQU 2408         ; Media address points outside of a valid range.
_HTTPC.STATUS.PPO_COUNT_INVALID EQU 2409         ; Count option points outside a valid media range.
_HTTPC.STATUS.TEXT_NOT_LOADED EQU 2410           ; The text was not defined.
_HTTPC.STATUS.TEXT_OFFSET_NOT_ALLOWED EQU 2411   ; Text offset is not allowed in lower (old) text segment.
_HTTPC.STATUS.DB_NOT_LOADED EQU 2412             ; The data block was not defined.
_HTTPC.STATUS.DB_ELEMENT_OUT_OF_RANGE EQU 2413   ; Access beyond the last data block element.
_HTTPC.STATUS.VALUE_OUT_OF_RANGE EQU 2414        ; Input value is not in valid range for the target media.
_HTTPC.STATUS.VALUE_READ_ONLY EQU 2415           ; Selected media is read only.
_HTTPC.STATUS.VALUE_SYNTAX_ERROR EQU 2416        ; Input value has a syntax error. Either the value is to big or a wrong format for the value.
_HTTPC.STATUS.VALUE_MISSING EQU 2417             ; Count value is higher than current input values. Response for write request with some values missing, e.g. PDP,,R0/3,x+1;;3

_HTTPC.STATUS.PPO_BIT_NOT_SUPPORTED EQU 2418     ; Specified media type does not support bit number suffix (supported only for xx7 I|Q|M|DB.DBX media type)
_HTTPC.STATUS.PPO_BIT_OUT_OF_RANGE EQU 2419      ; Bit number out of range, expected 0..7
_HTTPC.STATUS.PPO_INVALID_COUNT EQU 2420         ; More than 32 items of media code I|O|F cannot be transmitted at once

_HTTPC.STATUS.INVALID_LOCAL_MEDIA EQU 2451       ; Specified local media code is not supported.
_HTTPC.STATUS.LOCAL_AREA_OVERFLOW EQU 2452       ; Local media address points outside of a valid range.
_HTTPC.STATUS.LOCAL_DB_WRITE_FAIL EQU 2423       ; Specified DB does not exist, is not writable or DB item out of range

$ENDIF                                           ; $IFNDEF _LIBVERS_._SAIA_HTTPC_ERRORS

$LIST

;; End of file HTTPC_Errors.inc
